==> jc-1.4.0.tar.gz: soot/shimple/internal/analysis/DominanceFrontier.h <==
// public class soot.shimple.internal.analysis.DominanceFrontier

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f1bd878a4874fcce soot_shimple_internal_analysis_DominanceFrontier

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_shimple_internal_analysis_DominanceFrontier_H_
#define _JC_soot_shimple_internal_analysis_DominanceFrontier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_soot_shimple_internal_analysis_DominatorNode$object;

// Typedefs
typedef struct _jc_soot_shimple_internal_analysis_DominanceFrontier$sub_refs	_jc_soot_shimple_internal_analysis_DominanceFrontier$sub_refs;
typedef struct _jc_soot_shimple_internal_analysis_DominanceFrontier$sub_nonrefs	_jc_soot_shimple_internal_analysis_DominanceFrontier$sub_nonrefs;
typedef struct _jc_soot_shimple_internal_analysis_DominanceFrontier$refs	_jc_soot_shimple_internal_analysis_DominanceFrontier$refs;
typedef struct _jc_soot_shimple_internal_analysis_DominanceFrontier$nonrefs	_jc_soot_shimple_internal_analysis_DominanceFrontier$nonrefs;
typedef struct _jc_soot_shimple_internal_analysis_DominanceFrontier$object	_jc_soot_shimple_internal_analysis_DominanceFrontier$object;

typedef const struct _jc_soot_shimple_internal_analysis_DominanceFrontier$vmethods	_jc_soot_shimple_internal_analysis_DominanceFrontier$vmethods;
typedef const struct _jc_soot_shimple_internal_analysis_DominanceFrontier$vtable	_jc_soot_shimple_internal_analysis_DominanceFrontier$vtable;
typedef const struct _jc_soot_shimple_internal_analysis_DominanceFrontier$vtype	_jc_soot_shimple_internal_analysis_DominanceFrontier$vtype;

// Constructors
extern void _jc_soot_shimple_internal_analysis_DominanceFrontier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominanceFrontier$object *);
extern void _jc_soot_shimple_internal_analysis_DominanceFrontier$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominanceFrontier$object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_shimple_internal_analysis_DominanceFrontier$method$bottomUpDispatch$9de283e0f4160d5d(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominanceFrontier$object *, struct _jc_soot_shimple_internal_analysis_DominatorNode$object *);
extern void _jc_soot_shimple_internal_analysis_DominanceFrontier$method$processNode$8eecc4ea9fa1a626(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominanceFrontier$object *, struct _jc_soot_shimple_internal_analysis_DominatorNode$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_internal_analysis_DominanceFrontier$method_info$bottomUpDispatch$9de283e0f4160d5d;
extern _jc_method _jc_soot_shimple_internal_analysis_DominanceFrontier$method_info$processNode$8eecc4ea9fa1a626;

// Virtual methods structure
struct _jc_soot_shimple_internal_analysis_DominanceFrontier$vmethods {
	void	(*bottomUpDispatch$9de283e0f4160d5d)(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominanceFrontier$object *, struct _jc_soot_shimple_internal_analysis_DominatorNode$object *);
	void	(*processNode$8eecc4ea9fa1a626)(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominanceFrontier$object *, struct _jc_soot_shimple_internal_analysis_DominatorNode$object *);
};

// Vtable
struct _jc_soot_shimple_internal_analysis_DominanceFrontier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_shimple_internal_analysis_DominanceFrontier$vmethods	soot_shimple_internal_analysis_DominanceFrontier;
};

// Vtype
struct _jc_soot_shimple_internal_analysis_DominanceFrontier$vtype {
	_jc_type			type;
	_jc_soot_shimple_internal_analysis_DominanceFrontier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_internal_analysis_DominanceFrontier$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_internal_analysis_DominanceFrontier$refs {
    _jc_soot_shimple_internal_analysis_DominanceFrontier$sub_refs	soot_shimple_internal_analysis_DominanceFrontier;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_internal_analysis_DominanceFrontier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_internal_analysis_DominanceFrontier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_shimple_internal_analysis_DominanceFrontier$sub_nonrefs	soot_shimple_internal_analysis_DominanceFrontier;
};

// Object instance structure
struct _jc_soot_shimple_internal_analysis_DominanceFrontier$object {
	_jc_soot_shimple_internal_analysis_DominanceFrontier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_internal_analysis_DominanceFrontier$vtype	*vtype;
	_jc_soot_shimple_internal_analysis_DominanceFrontier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_internal_analysis_DominanceFrontier$vtype _jc_soot_shimple_internal_analysis_DominanceFrontier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_internal_analysis_DominanceFrontier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_internal_analysis_DominanceFrontier$class_object;

#endif	/* _JC_soot_shimple_internal_analysis_DominanceFrontier_H_ */

==> jc-1.4.6.tar.gz: soot/shimple/internal/analysis/DominanceFrontier.h <==
// public class soot.shimple.internal.analysis.DominanceFrontier

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f1bd878a4874fcce soot_shimple_internal_analysis_DominanceFrontier

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_shimple_internal_analysis_DominanceFrontier_H_
#define _JC_soot_shimple_internal_analysis_DominanceFrontier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_soot_shimple_internal_analysis_DominatorNode$object;

// Typedefs
typedef struct _jc_soot_shimple_internal_analysis_DominanceFrontier$sub_refs	_jc_soot_shimple_internal_analysis_DominanceFrontier$sub_refs;
typedef struct _jc_soot_shimple_internal_analysis_DominanceFrontier$sub_nonrefs	_jc_soot_shimple_internal_analysis_DominanceFrontier$sub_nonrefs;
typedef struct _jc_soot_shimple_internal_analysis_DominanceFrontier$refs	_jc_soot_shimple_internal_analysis_DominanceFrontier$refs;
typedef struct _jc_soot_shimple_internal_analysis_DominanceFrontier$nonrefs	_jc_soot_shimple_internal_analysis_DominanceFrontier$nonrefs;
typedef struct _jc_soot_shimple_internal_analysis_DominanceFrontier$object	_jc_soot_shimple_internal_analysis_DominanceFrontier$object;

typedef const struct _jc_soot_shimple_internal_analysis_DominanceFrontier$vmethods	_jc_soot_shimple_internal_analysis_DominanceFrontier$vmethods;
typedef const struct _jc_soot_shimple_internal_analysis_DominanceFrontier$vtable	_jc_soot_shimple_internal_analysis_DominanceFrontier$vtable;
typedef const struct _jc_soot_shimple_internal_analysis_DominanceFrontier$vtype	_jc_soot_shimple_internal_analysis_DominanceFrontier$vtype;

// Constructors
extern void _jc_soot_shimple_internal_analysis_DominanceFrontier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominanceFrontier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_shimple_internal_analysis_DominanceFrontier$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominanceFrontier$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_shimple_internal_analysis_DominanceFrontier$method$bottomUpDispatch$9de283e0f4160d5d(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominanceFrontier$object *, struct _jc_soot_shimple_internal_analysis_DominatorNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_shimple_internal_analysis_DominanceFrontier$method$processNode$8eecc4ea9fa1a626(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominanceFrontier$object *, struct _jc_soot_shimple_internal_analysis_DominatorNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_internal_analysis_DominanceFrontier$method_info$bottomUpDispatch$9de283e0f4160d5d;
extern _jc_method _jc_soot_shimple_internal_analysis_DominanceFrontier$method_info$processNode$8eecc4ea9fa1a626;

// Virtual methods structure
struct _jc_soot_shimple_internal_analysis_DominanceFrontier$vmethods {
	void	(*bottomUpDispatch$9de283e0f4160d5d)(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominanceFrontier$object *, struct _jc_soot_shimple_internal_analysis_DominatorNode$object *) _JC_JCNI_ATTR;
	void	(*processNode$8eecc4ea9fa1a626)(_jc_env *, struct _jc_soot_shimple_internal_analysis_DominanceFrontier$object *, struct _jc_soot_shimple_internal_analysis_DominatorNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_shimple_internal_analysis_DominanceFrontier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_shimple_internal_analysis_DominanceFrontier$vmethods	soot_shimple_internal_analysis_DominanceFrontier;
};

// Vtype
struct _jc_soot_shimple_internal_analysis_DominanceFrontier$vtype {
	_jc_type			type;
	_jc_soot_shimple_internal_analysis_DominanceFrontier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_internal_analysis_DominanceFrontier$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_internal_analysis_DominanceFrontier$refs {
    _jc_soot_shimple_internal_analysis_DominanceFrontier$sub_refs	soot_shimple_internal_analysis_DominanceFrontier;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_internal_analysis_DominanceFrontier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_internal_analysis_DominanceFrontier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_shimple_internal_analysis_DominanceFrontier$sub_nonrefs	soot_shimple_internal_analysis_DominanceFrontier;
};

// Object instance structure
struct _jc_soot_shimple_internal_analysis_DominanceFrontier$object {
	_jc_soot_shimple_internal_analysis_DominanceFrontier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_internal_analysis_DominanceFrontier$vtype	*vtype;
	_jc_soot_shimple_internal_analysis_DominanceFrontier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_internal_analysis_DominanceFrontier$vtype _jc_soot_shimple_internal_analysis_DominanceFrontier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_internal_analysis_DominanceFrontier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_internal_analysis_DominanceFrontier$class_object;

#endif	/* _JC_soot_shimple_internal_analysis_DominanceFrontier_H_ */
